import React, { useState } from 'react';
import { Prism as SyntaxHighlighter } from 'react-syntax-highlighter';
import { atomDark } from 'react-syntax-highlighter/dist/esm/styles/prism';
import SvgIcon from './SvgIcon';

/**
 * CodeBlock component renders a syntax highlighted code block with a copy button
 */
const CodeBlock = ({ language, value }) => {
    const [copied, setCopied] = useState(false);

    const handleCopy = () => {
        navigator.clipboard.writeText(value).then(() => {
            setCopied(true);
            // Reset the copied state after 2 seconds
            setTimeout(() => setCopied(false), 2000);
        });
    };

    return (
        <div className='code-block-container'>
            <div className='code-block-header'>
                {language && <span className='code-language-badge'>{language}</span>}
                <button onClick={handleCopy} className='copy-button' title={copied ? 'Copied!' : 'Copy code'}>
                    {copied ? (
                        <span className='copied-indicator'>✓ Copied!</span>
                    ) : (
                        <span className='copy-icon'>
                            <SvgIcon className='copy' width='16' height='16' />
                        </span>
                    )}
                </button>
            </div>
            <SyntaxHighlighter style={atomDark} language={language || 'text'} PreTag='div' wrapLongLines={true}>
                {value}
            </SyntaxHighlighter>
        </div>
    );
};

export default CodeBlock;
