import React, { useState } from 'react';
import { useSelector } from 'react-redux';
import '../styles/style.scss';

export default function UserSettingsModal({ show, onClose }) {
    const { user } = useSelector((state) => state.auth);
    const [lastPasswordChange] = useState('30天前'); // This would come from backend in real app

    if (!show) return null;

    return (
        <div className='modal show d-block' style={{ backgroundColor: 'rgba(0,0,0,0.5)' }}>
            <div className='modal-dialog modal-dialog-centered'>
                <div className='modal-content'>
                    <div className='modal-header border-0'>
                        <h5 className='modal-title'>管理员个人设置</h5>
                        <button type='button' className='btn-close' onClick={onClose}></button>
                    </div>
                    <div className='modal-body'>
                        <div className='mb-4'>
                            <h6 className='text-secondary mb-3'>个人信息</h6>
                            <div className='mb-3'>
                                <label className='form-label text-secondary'>姓名</label>
                                <input type='text' className='form-control' value={user?.username || ''} readOnly />
                            </div>
                            <div className='mb-3'>
                                <label className='form-label text-secondary'>邮箱</label>
                                <input
                                    type='email'
                                    className='form-control'
                                    value={user?.email || 'admin@ooin.com'}
                                    readOnly
                                />
                            </div>
                        </div>

                        <div className='mb-4'>
                            <h6 className='text-secondary mb-3'>安全设置</h6>
                            <div className='d-flex justify-content-between align-items-center p-3 bg-light rounded'>
                                <div>
                                    <div className='d-flex align-items-center gap-2'>
                                        <i className='bi bi-key'></i>
                                        <span>修改密码</span>
                                    </div>
                                    <small className='text-secondary'>上次修改：{lastPasswordChange}</small>
                                </div>
                                <button className='btn btn-outline-dark btn-sm'>修改</button>
                            </div>
                            <div className='d-flex justify-content-between align-items-center p-3 bg-light rounded mt-3'>
                                <div>
                                    <div className='d-flex align-items-center gap-2'>
                                        <i className='bi bi-shield-check'></i>
                                        <span>双重认证</span>
                                    </div>
                                    <small className='text-secondary'>增强账户安全性</small>
                                </div>
                                <button className='btn btn-outline-dark btn-sm'>设置</button>
                            </div>
                        </div>

                        <div>
                            <h6 className='text-secondary mb-3'>通知设置</h6>
                            <div className='form-check form-switch mb-3 dark-switch'>
                                <input
                                    className='form-check-input'
                                    type='checkbox'
                                    id='notificationSwitch1'
                                    defaultChecked
                                />
                                <label className='form-check-label' htmlFor='notificationSwitch1'>
                                    访问请求通知
                                </label>
                                <div className='text-secondary small'>新的数据集访问申请通知</div>
                            </div>
                            <div className='form-check form-switch dark-switch'>
                                <input
                                    className='form-check-input'
                                    type='checkbox'
                                    id='notificationSwitch2'
                                    defaultChecked
                                />
                                <label className='form-check-label' htmlFor='notificationSwitch2'>
                                    安全提醒
                                </label>
                                <div className='text-secondary small'>异常登录和权限变更提醒</div>
                            </div>
                        </div>
                    </div>
                    <div className='modal-footer border-0'>
                        <button type='button' className='btn btn-outline-dark' onClick={onClose}>
                            取消
                        </button>
                        <button type='button' className='btn btn-dark'>
                            保存更改
                        </button>
                    </div>
                </div>
            </div>
        </div>
    );
}
