import { post } from './api';

/**
 * 计算权限过期时间
 * @param {string} duration - 权限持续时间，如 '一周', '一个月', '三个月', '六个月', '永久'
 * @returns {string} - ISO 格式的日期字符串
 */
export const calculateExpiresAt = (duration) => {
    const now = new Date();
    switch (duration) {
        case '一周':
            now.setDate(now.getDate() + 7);
            break;
        case '一个月':
            now.setMonth(now.getMonth() + 1);
            break;
        case '三个月':
            now.setMonth(now.getMonth() + 3);
            break;
        case '六个月':
            now.setMonth(now.getMonth() + 6);
            break;
        case '永久':
            // 设置为较远的未来日期
            now.setFullYear(now.getFullYear() + 10);
            break;
        default:
            now.setDate(now.getDate() + 7);
    }
    return now.toISOString();
};

/**
 * 申请知识库访问权限（已废弃，请使用store/knowledgeBase/knowledgeBase.thunks中的requestKnowledgeBaseAccess）
 * @deprecated 请使用Redux thunk版本
 * @param {Object} requestData - 请求数据
 * @param {string} requestData.id - 知识库ID
 * @param {string} requestData.accessType - 访问类型，如 '只读访问', '编辑权限'
 * @param {string} requestData.duration - 访问时长，如 '一周', '一个月'
 * @param {string} requestData.reason - 申请原因
 * @returns {Promise} - API 请求的 Promise
 */
export const legacyRequestKnowledgeBaseAccess = async (requestData) => {
    const apiRequestData = {
        knowledge_base: requestData.id,
        permissions: {
            can_read: true,
            can_edit: requestData.accessType === '编辑权限',
            can_delete: false,
        },
        reason: requestData.reason,
        expires_at: calculateExpiresAt(requestData.duration),
    };

    return post('/permissions/', apiRequestData);
};
